Idea — Python reimplementation of NIXIO (http://g-node.github.io/nix/) 1.5.0 Development documentation

# Idea

The basic idea of the NIX project is to come up with a generic data model that defines as few structures/entities as possible while being able to represent a multitude of different data structures, allows for in-depth annotation and supports standardization.

Designing a generic data model implies that the defined entities are named in a way that may seem uncommon but are more general than the domain-specific terms used in any given field or community.

Please follow this link to the C++ nix library documentation to lear more about the data model.

The idea of the NIX data model has been implemented using the HDF5 file format.